.. pyspec documentation master file, created by
   sphinx-quickstart on Sun Oct 31 14:39:17 2010.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

==================================
Welcome to pyspec's documentation!
==================================

pyspec is a set of python routines for data analysis of x-ray
scattering experiments. It started out as a data class for the SPEC
x-ray diffractometer control program (http://www.certif.com/) but
since then has morphed into a suite of python classes for data
analysis. This has lead to the "bacronym" for pyspec being "python
routines for x-ray spectra analysis".

Contents:

.. toctree::
   :maxdepth: 3

   intro
   installation
   spec
   fit
   ccd
   diffractometer
   utils
   examples

==================
Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

